@@ -33,7 +33,9 @@
 #include "inpututils.h"
 #endif
 #include "mi.h"
+#include "mipointer.h"
 #include "exevents.h"
+#include "scrnintstr.h"
 #include "xkbsrv.h"
 #include "xkbstr.h"
 #include "xserver-properties.h"
@@ -72,7 +74,7 @@ static int vncKeyboardProc(DeviceIntPtr pDevice, int onoff);
 /*
  * Init input device.
  * This has to be called after core pointer/keyboard
- * initialization which unfortunately is after extesions
+ * initialization which unfortunately is after extensions
  * initialization (which means we cannot call it in
  * vncExtensionInit(). Check InitExtensions(),
  * InitCoreDevices() and InitInput() calls in dix/main.c.
@@ -186,8 +188,16 @@ void vncPointerMove(int x, int y)
 
 void vncGetPointerPos(int *x, int *y)
 {
-	if (vncPointerDev != NULL)
-		GetSpritePosition(vncPointerDev, &cursorPosX, &cursorPosY);
+	if (vncPointerDev != NULL) {
+		ScreenPtr ptrScreen;
+
+		miPointerGetPosition(vncPointerDev, &cursorPosX, &cursorPosY);
+
+		/* Pointer coordinates are screen relative */
+		ptrScreen = miPointerGetScreen(vncPointerDev);
+		cursorPosX += ptrScreen->x;
+		cursorPosY += ptrScreen->y;
+	}
 
 	*x = cursorPosX;
 	*y = cursorPosY;
@@ -300,6 +310,8 @@ static inline void pressKey(DeviceIntPtr dev, int kc, Bool down, const char *msg
 #if XORG < 111
 	n = GetKeyboardEvents(eventq, dev, action, kc);
 	enqueueEvents(dev, n);
+#elif XORG < 118
+	QueueKeyboardEvents(dev, action, kc, NULL);
 #else
 	QueueKeyboardEvents(dev, action, kc);
 #endif
